@@ -4,10 +4,9 @@ DSL APP
 import click
 from UsefulHelper.Tools.search import Search
 
-name = ''
+name: str = ''
 path = __file__
 
-
 '<def>'
 
 
